Comparing the Methods
=====================

This section consists of examples of 
each way to create conditions to illustrate
the similarities and differences.

Logic
^^^^^

**String syntax**

.. literalinclude:: /code/conds/syntax/logic.py
    :language: py

**Condition API**

.. literalinclude:: /code/conds/api/logic.py
    :language: py


Periodical Scheduling
^^^^^^^^^^^^^^^^^^^^^

**String syntax**

.. literalinclude:: /code/conds/syntax/periodical.py
    :language: py

**Condition API**

.. literalinclude:: /code/conds/api/periodical.py
    :language: py


Periodical Restricted Scheduling
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

**String syntax**

.. literalinclude:: /code/conds/syntax/periodical_restricted.py
    :language: py

**Condition API**

.. literalinclude:: /code/conds/api/periodical_restricted.py
    :language: py


Piping
^^^^^^

**String syntax**

.. literalinclude:: /code/conds/syntax/pipe_single.py
    :language: py

**Condition API**

.. literalinclude:: /code/conds/api/pipe_single.py
    :language: py

Piping Multiple
^^^^^^^^^^^^^^^

**String syntax**

.. literalinclude:: /code/conds/syntax/pipe_multiple.py
    :language: py

**Condition API**

.. literalinclude:: /code/conds/api/pipe_multiple.py
    :language: py